# this package links to the scripts Xsession and Xsetup from the xinitrc
# package. Check that these links are always matching each other, across the future
# versions, should their path change.
#
%define xinitrc_xdmpath %{_datadir}/X11/xdm

%define rel 4

%if %mgaver >= 10
%global use_qt6	1
%else
%global use_qt6	0
%endif

Name:		sddm
Version:	0.21.0
Release:	%mkrel %rel
License:	GPLv2+
Summary:	QML based X11 display manager
Group:		Graphical desktop/KDE
Url:		https://github.com/sddm/sddm
Source0:	https://github.com/sddm/sddm/archive/refs/tags/v%{version}/%{name}-%{version}.tar.gz
# PAM configs shamelessly stolen from our gdm package
Source1:	sddm.pam
Source2:	sddm-autologin.pam
# Adds sddm to drakedm
Source3:	11sddm.conf
# default /etc/sddm.conf, created from man sddm.conf
# similar can be obtained via sddm --example-config
# show users with UID >= 500 and hide system users
# allow display of custom user icons read from /var/lib/AccountsService/icons/
# ( by default SDDM reads user icon from either ~/.face.icon or FacesDir/username.face.icon )
Source6:	sddm.conf
# new default theme without a userlist, provided by Chris Denice
# https://bugs.mageia.org/show_bug.cgi?id=16493
# (patched from Papoteur included)
Source7:	mga-coffee-noflag.tar.gz
# sysconfig snippet
Source15: sddm.sysconfig
# workaround to enable autofocus on (password) input fields
# taken from examples at https://github.com/sddm/sddm/issues/501
Patch0:		sddm-0.12.0-mga-autofocus.patch
Patch2:		sddm-0.19.0-cmake-display-command.patch

# From FC
# Fix race with logind restart, and start seat0 if !CanGraphical on timer
# https://bugzilla.redhat.com/show_bug.cgi?id=2011991
# https://bugzilla.redhat.com/show_bug.cgi?id=2016310
# Submmited: https://github.com/sddm/sddm/pull/1494
Patch11:        0001-Delay-for-logind-and-fallback-to-seat0.patch
#
# sddm.service: +EnvironmentFile=-/etc/sysconfig/sddm
Patch103:       sddm-0.18.0-environment_file.patch

# from FC: Workaround lack of Qt 5 greeter build
Source105:       sddm-0.21.0-qt6greeter.patch

# Patches backported from git
Patch0201:	0001-VirtualTerminal-Export-defaultVtPath.patch
Patch0202:	0002-Allow-non-root-greeters-and-sessions-to-start-on-ker.patch
Patch0203:	0003-Conditionalize-more-VT-related-calls.patch
Patch0204:	0004-UserSession-Only-act-on-the-VT-when-XDG_VTNR-is-set.patch
Patch0205:	0005-Mark-keyboard-backend-as-disabled-on-Wayland.patch
Patch0206:	0006-Themes-hide-LayoutBox-when-keyboard-model-is-empty-o.patch
Patch0207:	0007-Themes-explicitly-resolve-image-URLs.patch
Patch0208:	0008-Components-use-Transitions-instead-of-Behaviors.patch
Patch0209:	0009-Themes-fix-deprecated-signal-handler-declarations.patch
Patch0210:	0010-Themes-set-QtVersion-QT_MAJOR_VERSION.patch
Patch0211:	0011-Docs-add-QtVersion-information-to-THEMING.patch
#
# https://github.com/sddm/sddm/pull/1951
Patch0300:	3024a1e0b7086089d3479588337cfa0440eddf95.patch
# deprecated workaround, to be reviewed
# https://github.com/sddm/sddm/issues/1917, https://github.com/sddm/sddm/pull/1924/
Patch0301:	111907ad7c604d264ec7bd078a7bcf1721d6eab8.patch

BuildRequires:	extra-cmake-modules
BuildRequires:	cmake
BuildRequires:	systemd-devel
BuildRequires:	upower-devel

BuildRequires:	pam-devel
BuildRequires:	python3-docutils
BuildRequires:	libxcb-devel
%if %use_qt6
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6DBus)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Help)
BuildRequires:	cmake(Qt6Qml)
BuildRequires:	cmake(Qt6Quick)
BuildRequires:	cmake(Qt6LinguistTools)
BuildRequires:	cmake(Qt6Test)
BuildRequires:	cmake(Qt6QuickTest)
%if %mgaver >= 10
BuildRequires:	cmake(LayerShellQt) >= 5.90
%endif
%else
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5DBus)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Qml)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Quick)
BuildRequires:	pkgconfig(Qt5Test)
BuildRequires:	pkgconfig(Qt5QuickTest)
%endif
BuildRequires:	cmake(LayerShellQt)

Obsoletes:	slim < 1.3.6
# /etc/dbus-1/system.d/org.freedesktop.DisplayManager.conf is also provided by lightdm,
# and the upgrade files if the packages are not updated in the same transaction (mga#18633)
Conflicts:	lightdm < 1.14.4-2

# For default background
Requires:	mageia-theme

# For themes, without this one gets
# "module "QtQuick" is not installed" errors
%if %use_qt6
Requires:	qt6-qtdeclarative
%else
Requires:	qtdeclarative5
%endif

Requires:	xinitrc
Requires:	pam
Requires:	systemd
Requires:	x11-server-xorg
Requires(post):	systemd
Requires(preun): systemd
Requires(postun): systemd

%description
SDDM is a modern display manager for X11 aiming to be fast, simple and
beautiful. It uses modern technologies like QtQuick, which in turn gives the
designer the ability to create smooth, animated user interfaces.

%prep
%autosetup -p1
%if %use_qt6
patch -p1 < %{SOURCE105}
%endif

# use default mga background image in themes
#
# (doktor5000) - this makes most part of the themes useless and ugly (default.jpg is not resolution-optimized)
# instead, a separate Mageia theme is created further below and used by default
# sed -i -e 's,\(^background=\).*,\1%{_datadir}/mga/backgrounds/default.jpg,' data/themes/*/theme.conf


%build
# set UID_MIN and UID_MAX here as autodetection from /etc/login.defs is not
# possible for normal users due to missing read permissions
%if %use_qt6
%cmake_qt6 \
	-DBUILD_WITH_QT6:BOOL=ON \
%else
%cmake_qt5 \
%endif
	-DBUILD_MAN_PAGES=ON \
	-DDBUS_CONFIG_FILENAME:STRING=org.freedesktop.DisplayManager-sddm.conf \
	-DENABLE_JOURNALD=ON \
	-DUID_MIN=500 \
	-DUID_MAX=60000

%cmake_build

%install
%cmake_install

# dm config
install -Dpm 644 %{_sourcedir}/11sddm.conf %{buildroot}%{_datadir}/X11/dm.d/11sddm.conf

mkdir -p %{buildroot}%{_sysconfdir}/sddm/
mkdir -p %{buildroot}%{_sysconfdir}/sddm.conf.d
mkdir -p %{buildroot}%{_prefix}/lib/sddm/sddm.conf.d
mkdir -p %{buildroot}%{_rundir}/sddm

# PAM config stolen from our gdm package
install -Dpm 644 %{_sourcedir}/sddm.pam %{buildroot}%{_sysconfdir}/pam.d/sddm
install -Dpm 644 %{_sourcedir}/sddm-autologin.pam %{buildroot}%{_sysconfdir}/pam.d/sddm-autologin
install -Dpm 644 %{SOURCE15} %{buildroot}%{_sysconfdir}/sysconfig/sddm

# system user home dir
mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}

# extract new default theme mga-coffee
tar -xf %{SOURCE7} -C %{buildroot}%{_datadir}/sddm/themes
sed -i 's/jpg/png/' %{buildroot}%{_datadir}/sddm/themes/mga-coffee/theme.conf

# replace upstream Xsession and Xsetup scripts with the same links from the xinitrc package
# (and preserve the upstream Xsession and Xsetup under the names Xsession.sddm and Xsetup.sddm)
mv -f %{buildroot}%{_datadir}/sddm/scripts/Xsession %{buildroot}%{_datadir}/sddm/scripts/Xsession.sddm
mv -f %{buildroot}%{_datadir}/sddm/scripts/Xsetup %{buildroot}%{_datadir}/sddm/scripts/Xsetup.sddm
ln -sf %{xinitrc_xdmpath}/Xsession %{buildroot}%{_datadir}/sddm/scripts/Xsession
ln -sf %{xinitrc_xdmpath}/Xsetup_0 %{buildroot}%{_datadir}/sddm/scripts/Xsetup

# install default sddm.conf
install -Dpm 644 %{_sourcedir}/sddm.conf %{buildroot}%{_sysconfdir}/

# fix mgangle.png icon permission
find %{buildroot}%{_datadir} -not -type d -a \( -type f -name '*.png' \) -perm /u=x,g=x,o=x -exec chmod -x '{}' \;

%if %use_qt6
ln -sr %{buildroot}%{_bindir}/sddm-greeter-qt6 %{buildroot}%{_bindir}/sddm-greeter
%endif

# (ngompa) pretrans must be Lua
# See https://fedoraproject.org/wiki/User:Patches/PackagingDrafts/Symlink_Workarounds
%pretrans -p <lua>
xsetuppath = "%{_datadir}/sddm/scripts/Xsetup"
st1 = posix.stat(xsetuppath)
if st1 and st1.type ~= "link" then
  os.execute("rm -f " .. xsetuppath)
end

xsessionpath = "%{_datadir}/sddm/scripts/Xsession"
st2 = posix.stat(xsessionpath)
if st2 and st2.type ~= "link" then
  os.execute("rm -f " .. xsessionpath)
end

%pre
%_pre_useradd %{name} %{_localstatedir}/lib/%{name} /sbin/nologin

%if 0
%post
%_post_service sddm

%preun
%_preun_service sddm
%endif


%files
%license LICENSE
%doc README.md CONTRIBUTORS
%dir %{_sysconfdir}/sddm/
%dir %{_sysconfdir}/sddm.conf.d
%dir %{_prefix}/lib/sddm
%dir %{_prefix}/lib/sddm/sddm.conf.d
%ghost %attr(0711,root,sddm) %dir %{_rundir}/%{name}
%attr(700,sddm,sddm) %{_localstatedir}/lib/%{name}/
%config(noreplace) %{_sysconfdir}/sddm.conf
%config(noreplace) %{_sysconfdir}/pam.d/sddm
%config(noreplace) %{_sysconfdir}/pam.d/sddm-autologin
%config(noreplace) %{_sysconfdir}/pam.d/sddm-greeter
%config(noreplace) %{_sysconfdir}/sysconfig/sddm
%{_datadir}/X11/dm.d/11sddm.conf
%{_datadir}/dbus-1/system.d/org.freedesktop.DisplayManager-sddm.conf
%{_libexecdir}/sddm-helper
%{_bindir}/sddm
%{_bindir}/sddm-greeter*
%{_unitdir}/sddm.service
%if %use_qt6
%if %mgaver >= 10
%{_qt6_qmldir}/SddmComponents/
%else
%{_qt6_archdatadir}/qml/SddmComponents/
%endif
%else
%{_qt5_qml}/SddmComponents
%endif
%dir %{_datadir}/sddm
%{_datadir}/sddm/faces
%{_datadir}/sddm/scripts
%{_datadir}/sddm/themes
%{_datadir}/sddm/flags
%{_datadir}/sddm/translations*
%{_mandir}/man?/%{name}*
%{_sysusersdir}/sddm.conf
%{_tmpfilesdir}/sddm.conf
%{_libexecdir}/sddm-helper-start-wayland
%{_libexecdir}/sddm-helper-start-x11user


%changelog
* Sat Aug 10 2024 daviddavid <daviddavid> 0.21.0-4.mga10
+ Revision: 2085263
- rebuild for new Qt 6.7.2

* Sat Jul 06 2024 ghibo <ghibo> 0.21.0-3.mga10
+ Revision: 2080138
- Merge patch to fix german translations.
- Merge patch to fix race conditions with DRM GPU loading.
+ daviddavid <daviddavid>
- rebuild for i686

* Sun Mar 31 2024 ghibo <ghibo> 0.21.0-2.mga10
+ Revision: 2053471
- Add a missed %%else in conditional build

* Sun Mar 31 2024 ghibo <ghibo> 0.21.0-1.mga10
+ Revision: 2053463
- Temporary build flags for i586
- Update to release 0.21.0.
- Add flag to allow build with Qt6 conditionally.
- Drop Patch12 no longer required.
- Merge patch from FC (Source105) to default to Qt6 and allow versioned sddm-greater.
- Merge patches from git upstream.
- Rename dbus org.freedesktop.DisplayManager.conf to org.freedesktop.DisplayManager-sddm.conf to avoid conflicts with other display managers.

* Thu Jan 04 2024 daviddavid <daviddavid> 0.20.0-6.mga10
+ Revision: 2027613
- switch to Qt6 for Plasma6

* Sat Dec 09 2023 ghibo <ghibo> 0.20.0-5.mga10
+ Revision: 2016324
- Merge patch from upstream to prevent tmpfiles removing old xauth files

* Fri Dec 01 2023 ghibo <ghibo> 0.20.0-4.mga10
+ Revision: 2012590
- Merge patch from git upstream.
- Merge patch from FC to correctly integrate the greeter with layer-shell and fix BuildRequires.

* Tue Sep 26 2023 daviddavid <daviddavid> 0.20.0-3.mga10
+ Revision: 1991026
- Artwork for Mga9

* Sun Sep 24 2023 ghibo <ghibo> 0.20.0-2.mga10
+ Revision: 1990361
- Merge two more patches from git upstream

* Fri Sep 01 2023 ghibo <ghibo> 0.20.0-1.mga10
+ Revision: 1983187
- Mark %%_rundir/sddm as %%ghost
- Update to release 0.20.0.
- Add /etc/sddm/sddm.d dir.
- Sync with FC.
- Update sddm.conf.
- Cleanup old unused (maui) code in SPEC file.
- Merge patches from git upstream.
- Add missed BR.

* Tue Jul 05 2022 papoteur <papoteur> 0.19.0-16.mga9
+ Revision: 1867760
- fix build failing on XorgDisplayServer use of deleted function sddm#1536
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Feb 23 2021 neoclust <neoclust> 0.19.0-15.mga9
+ Revision: 1675681
- Set RememberLastSession to true (mga#28378)

* Thu Feb 18 2021 daviddavid <daviddavid> 0.19.0-14.mga8
+ Revision: 1675601
- add upstream patch to change "User name" to "Username" for every translations

* Tue Feb 16 2021 neoclust <neoclust> 0.19.0-13.mga8
+ Revision: 1675458
- Remove new mageia theme as it is postponed for mageia 9

* Mon Feb 15 2021 neoclust <neoclust> 0.19.0-12.mga8
+ Revision: 1675443
- Do not show userlist in mageia theme

* Mon Feb 15 2021 neoclust <neoclust> 0.19.0-11.mga8
+ Revision: 1675439
- New version of mageia theme

* Sat Feb 13 2021 neoclust <neoclust> 0.19.0-10.mga8
+ Revision: 1675331
- workaround permission issue on mageia theme

* Sat Feb 13 2021 neoclust <neoclust> 0.19.0-9.mga8
+ Revision: 1675303
- Use new mageia theme as default

* Sat Feb 13 2021 neoclust <neoclust> 0.19.0-8.mga8
+ Revision: 1675302
- Fix default mageia theme

* Fri Feb 12 2021 neoclust <neoclust> 0.19.0-7.mga8
+ Revision: 1675234
- Use Theme from mga#24861 needs a lot of tests

* Fri Jan 22 2021 tmb <tmb> 0.19.0-6.mga8
+ Revision: 1672887
- Merge normal and testing paths in XorgDisplayServer::start
- Explicitly stop Xorg when starting fails
- Emit XorgDisplayServer::started only when the auth file isready

* Fri Jan 22 2021 tmb <tmb> 0.19.0-5.mga8
+ Revision: 1672879
- Retry starting the display server

* Mon Jan 11 2021 daviddavid <daviddavid> 0.19.0-4.mga8
+ Revision: 1671023
- add upstream patch to fix french translation from User name to Username (mga#28065)

* Thu Dec 17 2020 umeabot <umeabot> 0.19.0-3.mga8
+ Revision: 1659777
- Rebuild for new Qt5

* Thu Nov 12 2020 wally <wally> 0.19.0-2.mga8
+ Revision: 1644885
- don't log nopasswdlogin failures to syslog

* Sun Nov 08 2020 daviddavid <daviddavid> 0.19.0-1.mga8
+ Revision: 1643684
- new version: 0.19.0, fixes CVE-2020-28049 (mga#27565)

* Tue Feb 25 2020 daviddavid <daviddavid> 0.18.1-4.mga8
+ Revision: 1550455
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Fri May 24 2019 wally <wally> 0.18.1-3.mga7
+ Revision: 1399024
- fix pam config to unlock gnome-keyring and kwallet at login

* Sun May 12 2019 wally <wally> 0.18.1-2.mga7
+ Revision: 1397358
- add pam support for unlocking gnome keyring and kwallet when login

* Thu Apr 11 2019 daviddavid <daviddavid> 0.18.1-1.mga7
+ Revision: 1388352
- new version: 0.18.1

* Tue Apr 02 2019 daviddavid <daviddavid> 0.18.0-4.mga7
+ Revision: 1384746
- Qt5 Rebuild

* Wed Jan 23 2019 daviddavid <daviddavid> 0.18.0-3.mga7
+ Revision: 1360332
- rst2man is now provided by python3-docutils

* Wed Dec 26 2018 tmb <tmb> 0.18.0-2.mga7
+ Revision: 1345025
- dont enable/activate qtvirtualkeyboard by default even if it is installed

* Mon Dec 24 2018 tmb <tmb> 0.18.0-1.mga7
+ Revision: 1344846
- update to 0.18.0

* Fri Oct 05 2018 daviddavid <daviddavid> 0.17.0-5.mga7
+ Revision: 1317851
- Mageia 7 Mass Rebuild

* Fri Jun 08 2018 daviddavid <daviddavid> 0.17.0-4.mga7
+ Revision: 1235305
- add patch to fix build with new Qt5 >= 5.11.0

* Fri Jan 19 2018 mrambo3501 <mrambo3501> 0.17.0-3.mga7
+ Revision: 1194656
+ rebuild (emptylog)

* Thu Jan 18 2018 mrambo3501 <mrambo3501> 0.17.0-2.mga7
+ Revision: 1194476
- modify bundled mga-coffee theme to blank an incorrect password mga#19988
- increase the incorrect password message font size mga#19988:C1

* Mon Dec 25 2017 ghibo <ghibo> 0.17.0-1.mga7
+ Revision: 1184797
- Update to release 0.17.0.
- Update to release 0.16.0.
- Remove git patches (merged upstream).

* Thu Mar 16 2017 eatdirt <eatdirt> 0.14.0-13.mga6
+ Revision: 1093206
- Remove flag and fix desktop file (#16493)

* Sat Dec 10 2016 ngompa <ngompa> 0.14.0-12.mga6
+ Revision: 1074062
- Convert %%pretrans to Lua

* Fri Nov 25 2016 ghibo <ghibo> 0.14.0-11.mga6
+ Revision: 1070095
- Merges patches from git or bug #18822 and others from git.
- Fix a typo in sddm.conf for Enabling/Disabling HiDPI.
- Clean sddm.conf from unused themes.
- Preseve upstream XSession and Xsetup under XSession.sddm and Xsetup.sddm names.

* Mon Oct 24 2016 ghibo <ghibo> 0.14.0-10.mga6
+ Revision: 1063430
- Make SPEC file more robust across updates and add %%posttrans for replacing files with links.

* Sun Oct 23 2016 ghibo <ghibo> 0.14.0-9.mga6
+ Revision: 1063332
- Added Patch to support DisplayCommand configure path in cmake command line.
- Backport upstream patch to support HiDPI displays (bug sddm#701).
- Usr /usr/share/X11/xdm/Xsetup_0 and /usr/share/X11/xdm/Xsession script soft links as suggested by Charles Edwards in bug #19601.

* Mon Oct 17 2016 neoclust <neoclust> 0.14.0-8.mga6
+ Revision: 1061252
- Use fixed sddm.conf ( Giuseppe Ghibò )  mga#19601

* Sun Oct 16 2016 tv <tv> 0.14.0-7.mga6
+ Revision: 1061013
- switch to %%autosetup (mga#15579)

* Wed Sep 28 2016 neoclust <neoclust> 0.14.0-6.mga6
+ Revision: 1057448
- Improve swedish translation

* Tue Sep 20 2016 neoclust <neoclust> 0.14.0-5.mga6
+ Revision: 1054613
- Revert xsession commit

* Mon Sep 19 2016 ghibo <ghibo> 0.14.0-4.mga6
+ Revision: 1054511
- fix mgangle.png icon permission

* Mon Sep 19 2016 neoclust <neoclust> 0.14.0-3.mga6
+ Revision: 1054166
- Try using upstream Xsession

* Thu Sep 15 2016 barjac <barjac> 0.14.0-2.mga6
+ Revision: 1053243
- change default.jpg to default.png in mga-coffee theme.conf

* Mon Sep 12 2016 neoclust <neoclust> 0.14.0-1.mga6
+ Revision: 1051630
- New version 0.14.0

* Thu Aug 11 2016 schultz <schultz> 0.13.0-7.mga6
+ Revision: 1045781
- theme for mga6 (mga#19045)
- update theme for mga6 (mga#19045)

* Fri Jul 22 2016 tmb <tmb> 0.13.0-6.mga6
+ Revision: 1043165
- drop mistakenly added 'RememberLastUser=false' in sddm.conf

* Fri Jul 22 2016 tmb <tmb> 0.13.0-5.mga6
+ Revision: 1043098
- Honor RememberLastUser and RememberLastSession settings
- Activate window for the primary screen
- Quit SDDM if X fails to start

* Wed Jun 22 2016 akien <akien> 0.13.0-4.mga6
+ Revision: 1037170
- Add a conflict with mga5 lightdm to fix upgrade path (mga#18633)
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Dec 09 2015 neoclust <neoclust> 0.13.0-2.mga6
+ Revision: 909140
- Add P1: Fix crash reading lists from configuration

* Mon Nov 09 2015 doktor5000 <doktor5000> 0.13.0-1.mga6
+ Revision: 900206
- new version 0.13

* Thu Nov 05 2015 doktor5000 <doktor5000> 0.12.0-4.mga6
+ Revision: 898008
- add workaround to enable autofocus on input field (mga#17073)
- do not use /var/lib/AccountsService/icons for user faces/icons, use default
  o would require accountsservice to be installed

* Thu Nov 05 2015 wally <wally> 0.12.0-3.mga6
+ Revision: 897920
- rebuild with latest rpm to fix weird file conflict issue that shouldn't happen

* Thu Oct 15 2015 doktor5000 <doktor5000> 0.12.0-2.mga6
+ Revision: 891922
- added patch for CVE-2015-0856 (mga#16966)
  o prevent themes from loading KDE crash handler

* Sat Oct 03 2015 doktor5000 <doktor5000> 0.12.0-1.mga6
+ Revision: 886043
- new version 0.12
  o SDDM now depends on Qt >= 5.3
  o Display setup script is now killed if it hasn't finished within 30 seconds
  o new default X ServerArguments "-nolisten tcp"
  o wayland sessions support
- added newly supported options as comments to %%{_sysconfdir}/sddm.conf
- added mga-coffee as new default theme provided by Chris Denice
  o disables display of userlist, fixes (mga#16493)
- fix display of text messages in front of Mageia logo with mga-maui theme
- allow display of user icons from /var/lib/AccountsService/icons
- hide more system users on login screen
  o mysql,apache and mldonkey via HideUsers as they use real shells
  o openvpn via HideShells as it uses /bin/false
- specify MIN_UID and MAX_UID directly as autodetection from /etc/login.defs
  is not possible due to no read permission for others

* Wed Dec 03 2014 doktor5000 <doktor5000> 0.11.0-1.mga5
+ Revision: 800515
- new version 0.11.0
- drop Patch to use system locale on greeter start, merged upstream
- really update numix theme to work with sddm >= 0.10.0
- do not change background for all themes to Mageia default background
- create and use custom Mageia theme based on Maui as default
- updated URL to new naming scheme, reenables automatic downloads

* Fri Nov 21 2014 doktor5000 <doktor5000> 0.10.0-5.mga5
+ Revision: 798141
- added /usr/sbin/nologin to HideShells stanza

* Thu Nov 20 2014 doktor5000 <doktor5000> 0.10.0-4.mga5
+ Revision: 797925
- add Patch to use system locale on greeter start
  o from upstream https://github.com/sddm/sddm/pull/312
- remove pam_gnome_keyring.so to fix the impossibility to log out (rhbz#1150283)
- use %%config(noreplace) for /etc/sddm.conf
- add default /etc/sddm.conf with comments on all stanzas
  o allows to show users with UID >= 500 for upgrades from mga4 (mga#11401)
  o hides system users (with login shells /sbin/nologin and /bin/false for now)

* Sat Oct 25 2014 doktor5000 <doktor5000> 0.10.0-2.mga5
+ Revision: 793095
- add numix theme from http://intialonso.github.io/ based on Maui theme

* Fri Oct 24 2014 doktor5000 <doktor5000> 0.10.0-1.mga5
+ Revision: 793031
- new version 0.10.0
- security issues fixed (mga#14238) :
  o Never try to login as the sddm user (CVE-2014-7271)
  o Fix race condition in XAUTHORITY file generation (CVE-2014-7272)
  o XAUTHORITY file is no longer owned by root
- drops QT4 support
- fixes PAM variable handling and some autologin issues

* Wed Oct 15 2014 umeabot <umeabot> 0.9.0-10.mga5
+ Revision: 740556
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.0-9.mga5
+ Revision: 689088
- Mageia 5 Mass Rebuild

* Thu Sep 04 2014 colin <colin> 0.9.0-8.mga5
+ Revision: 671891
- Rebuild for new systemd

* Wed Aug 27 2014 wally <wally> 0.9.0-7.mga5
+ Revision: 668797
- require xinitrc

* Wed Aug 06 2014 wally <wally> 0.9.0-6.mga5
+ Revision: 660249
- obsolete slim
- require qtdeclarative5 for themes

* Wed Aug 06 2014 wally <wally> 0.9.0-5.mga5
+ Revision: 660199
- use default Mageia background image in themes
- add dm config file to add sddm to drakedm
- use pam config files from our gdm (sddm and sddm-autologin)

* Wed Aug 06 2014 wally <wally> 0.9.0-4.mga5
+ Revision: 660143
- disable systemd post/preun scripts for now
- create sddm system user for greeter
- tag pam config files as %%config(noreplace)
- build man pages

* Wed Aug 06 2014 neoclust <neoclust> 0.9.0-3.mga5
+ Revision: 660110
- Build against Qt5

* Tue Aug 05 2014 neoclust <neoclust> 0.9.0-2.mga5
+ Revision: 659889
- Fix login (P0)

* Sat Aug 02 2014 neoclust <neoclust> 0.9.0-1.mga5
+ Revision: 659261
- New version 0.9.0

* Sat Oct 19 2013 umeabot <umeabot> 0.1.0-7.mga4
+ Revision: 531342
- Mageia 4 Mass Rebuild

* Sun Aug 04 2013 sander85 <sander85> 0.1.0-6.mga4
+ Revision: 463132
- Fix requires

* Sat Aug 03 2013 neoclust <neoclust> 0.1.0-5.mga4
+ Revision: 462782
- imported package sddm


* Mon Jul 22 2013 Martin Briza <mbriza@redhat.com> - 0.1.0-5
- Store xauth in /var/run/sddm

* Mon Jul 22 2013 Martin Briza <mbriza@redhat.com> - 0.1.0-4
- Added the documentation bits

* Thu Jul 18 2013 Martin Briza <mbriza@redhat.com> - 0.1.0-3
- Changed the source package to tar.gz
- Config files are now noreplace
- Buildrequires -systemd-devel +systemd +cmake

* Tue Jul 16 2013 Martin Briza <mbriza@redhat.com> - 0.1.0-2
- Removed unneeded BuildRequires
- Fixed systemd scriptlets
- Fixed release
- Simplified setup
- Added Requires needed for basic function
- Added Provides for graphical login

* Thu Jul 04 2013 Martin Briza <mbriza@redhat.com> - 0.1.0-1
- Initial build
